==> kubernetes-model-1.0.37-sources.jar: io/fabric8/kubernetes/api/model/ComponentConditionFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;

public class ComponentConditionFluentImpl<T extends ComponentConditionFluent<T>> extends BaseFluent<T> implements ComponentConditionFluent<T>{

     String error;     String message;     String status;     String type;     Map<String, Object> additionalProperties = new HashMap();
public ComponentConditionFluentImpl(){
    
}
public ComponentConditionFluentImpl( ComponentCondition instance ){
    this.withError(instance.getError()); this.withMessage(instance.getMessage()); this.withStatus(instance.getStatus()); this.withType(instance.getType()); 
}

    public String getError(){
    return this.error;
    }
    public T withError( String error){
    this.error=error; return (T) this;
    }
    public String getMessage(){
    return this.message;
    }
    public T withMessage( String message){
    this.message=message; return (T) this;
    }
    public String getStatus(){
    return this.status;
    }
    public T withStatus( String status){
    this.status=status; return (T) this;
    }
    public String getType(){
    return this.type;
    }
    public T withType( String type){
    this.type=type; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ComponentConditionFluentImpl that = (ComponentConditionFluentImpl) o;
if (error != null ? !error.equals(that.error) :that.error != null) return false;
if (message != null ? !message.equals(that.message) :that.message != null) return false;
if (status != null ? !status.equals(that.status) :that.status != null) return false;
if (type != null ? !type.equals(that.type) :that.type != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.50-sources.jar: io/fabric8/kubernetes/api/model/ComponentConditionFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class ComponentConditionFluentImpl<A extends ComponentConditionFluent<A>> extends BaseFluent<A> implements ComponentConditionFluent<A>{

     String error;     String message;     String status;     String type;
public ComponentConditionFluentImpl(){
    
}
public ComponentConditionFluentImpl( ComponentCondition instance ){
    this.withError(instance.getError()); this.withMessage(instance.getMessage()); this.withStatus(instance.getStatus()); this.withType(instance.getType()); 
}

    public String getError(){
    return this.error;
    }
    public A withError( String error){
    this.error=error; return (A) this;
    }
    public String getMessage(){
    return this.message;
    }
    public A withMessage( String message){
    this.message=message; return (A) this;
    }
    public String getStatus(){
    return this.status;
    }
    public A withStatus( String status){
    this.status=status; return (A) this;
    }
    public String getType(){
    return this.type;
    }
    public A withType( String type){
    this.type=type; return (A) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ComponentConditionFluentImpl that = (ComponentConditionFluentImpl) o;
if (error != null ? !error.equals(that.error) :that.error != null) return false;
if (message != null ? !message.equals(that.message) :that.message != null) return false;
if (status != null ? !status.equals(that.status) :that.status != null) return false;
if (type != null ? !type.equals(that.type) :that.type != null) return false;
return true;

    }



}
